# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Applicant(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'datetime',
        'delete_at': 'datetime',
        'href': 'str',
        'sandbox': 'bool',
        'title': 'str',
        'first_name': 'str',
        'middle_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'gender': 'str',
        'dob': 'date',
        'telephone': 'str',
        'mobile': 'str',
        'country': 'str',
        'nationality': 'str',
        'mothers_maiden_name': 'str',
        'country_of_birth': 'str',
        'town_of_birth': 'str',
        'previous_last_name': 'str',
        'addresses': 'list[Address]',
        'id_numbers': 'list[IdNumber]'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'created_at',
        'delete_at': 'delete_at',
        'href': 'href',
        'sandbox': 'sandbox',
        'title': 'title',
        'first_name': 'first_name',
        'middle_name': 'middle_name',
        'last_name': 'last_name',
        'email': 'email',
        'gender': 'gender',
        'dob': 'dob',
        'telephone': 'telephone',
        'mobile': 'mobile',
        'country': 'country',
        'nationality': 'nationality',
        'mothers_maiden_name': 'mothers_maiden_name',
        'country_of_birth': 'country_of_birth',
        'town_of_birth': 'town_of_birth',
        'previous_last_name': 'previous_last_name',
        'addresses': 'addresses',
        'id_numbers': 'id_numbers'
    }

    def __init__(self, id=None, created_at=None, delete_at=None, href=None, sandbox=None, title=None, first_name=None, middle_name=None, last_name=None, email=None, gender=None, dob=None, telephone=None, mobile=None, country=None, nationality=None, mothers_maiden_name=None, country_of_birth=None, town_of_birth=None, previous_last_name=None, addresses=None, id_numbers=None):  # noqa: E501
        """Applicant - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._created_at = None
        self._delete_at = None
        self._href = None
        self._sandbox = None
        self._title = None
        self._first_name = None
        self._middle_name = None
        self._last_name = None
        self._email = None
        self._gender = None
        self._dob = None
        self._telephone = None
        self._mobile = None
        self._country = None
        self._nationality = None
        self._mothers_maiden_name = None
        self._country_of_birth = None
        self._town_of_birth = None
        self._previous_last_name = None
        self._addresses = None
        self._id_numbers = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if delete_at is not None:
            self.delete_at = delete_at
        if href is not None:
            self.href = href
        if sandbox is not None:
            self.sandbox = sandbox
        if title is not None:
            self.title = title
        if first_name is not None:
            self.first_name = first_name
        if middle_name is not None:
            self.middle_name = middle_name
        if last_name is not None:
            self.last_name = last_name
        if email is not None:
            self.email = email
        if gender is not None:
            self.gender = gender
        if dob is not None:
            self.dob = dob
        if telephone is not None:
            self.telephone = telephone
        if mobile is not None:
            self.mobile = mobile
        if country is not None:
            self.country = country
        if nationality is not None:
            self.nationality = nationality
        if mothers_maiden_name is not None:
            self.mothers_maiden_name = mothers_maiden_name
        if country_of_birth is not None:
            self.country_of_birth = country_of_birth
        if town_of_birth is not None:
            self.town_of_birth = town_of_birth
        if previous_last_name is not None:
            self.previous_last_name = previous_last_name
        if addresses is not None:
            self.addresses = addresses
        if id_numbers is not None:
            self.id_numbers = id_numbers

    @property
    def id(self):
        """Gets the id of this Applicant.  # noqa: E501

        The unique identifier for the applicant. Read-only.  # noqa: E501

        :return: The id of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Applicant.

        The unique identifier for the applicant. Read-only.  # noqa: E501

        :param id: The id of this Applicant.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this Applicant.  # noqa: E501

        The date and time when this applicant was created. Read-only.  # noqa: E501

        :return: The created_at of this Applicant.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Applicant.

        The date and time when this applicant was created. Read-only.  # noqa: E501

        :param created_at: The created_at of this Applicant.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def delete_at(self):
        """Gets the delete_at of this Applicant.  # noqa: E501

        The date and time when this applicant is scheduled to be deleted. Read-only.  # noqa: E501

        :return: The delete_at of this Applicant.  # noqa: E501
        :rtype: datetime
        """
        return self._delete_at

    @delete_at.setter
    def delete_at(self, delete_at):
        """Sets the delete_at of this Applicant.

        The date and time when this applicant is scheduled to be deleted. Read-only.  # noqa: E501

        :param delete_at: The delete_at of this Applicant.  # noqa: E501
        :type: datetime
        """

        self._delete_at = delete_at

    @property
    def href(self):
        """Gets the href of this Applicant.  # noqa: E501

        The uri of this resource. Read-only.  # noqa: E501

        :return: The href of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this Applicant.

        The uri of this resource. Read-only.  # noqa: E501

        :param href: The href of this Applicant.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def sandbox(self):
        """Gets the sandbox of this Applicant.  # noqa: E501

        Read-only.  # noqa: E501

        :return: The sandbox of this Applicant.  # noqa: E501
        :rtype: bool
        """
        return self._sandbox

    @sandbox.setter
    def sandbox(self, sandbox):
        """Sets the sandbox of this Applicant.

        Read-only.  # noqa: E501

        :param sandbox: The sandbox of this Applicant.  # noqa: E501
        :type: bool
        """

        self._sandbox = sandbox

    @property
    def title(self):
        """Gets the title of this Applicant.  # noqa: E501

        The applicant’s title  # noqa: E501

        :return: The title of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Applicant.

        The applicant’s title  # noqa: E501

        :param title: The title of this Applicant.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def first_name(self):
        """Gets the first_name of this Applicant.  # noqa: E501

        The applicant’s first name  # noqa: E501

        :return: The first_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Applicant.

        The applicant’s first name  # noqa: E501

        :param first_name: The first_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def middle_name(self):
        """Gets the middle_name of this Applicant.  # noqa: E501

        The applicant’s middle name(s) or initial  # noqa: E501

        :return: The middle_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """Sets the middle_name of this Applicant.

        The applicant’s middle name(s) or initial  # noqa: E501

        :param middle_name: The middle_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._middle_name = middle_name

    @property
    def last_name(self):
        """Gets the last_name of this Applicant.  # noqa: E501

        The applicant’s surname  # noqa: E501

        :return: The last_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Applicant.

        The applicant’s surname  # noqa: E501

        :param last_name: The last_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this Applicant.  # noqa: E501

        The applicant’s email address. Required if doing a US check or a standard UK check.  # noqa: E501

        :return: The email of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Applicant.

        The applicant’s email address. Required if doing a US check or a standard UK check.  # noqa: E501

        :param email: The email of this Applicant.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def gender(self):
        """Gets the gender of this Applicant.  # noqa: E501

        The applicant’s gender. Valid values are male and female.  # noqa: E501

        :return: The gender of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this Applicant.

        The applicant’s gender. Valid values are male and female.  # noqa: E501

        :param gender: The gender of this Applicant.  # noqa: E501
        :type: str
        """

        self._gender = gender

    @property
    def dob(self):
        """Gets the dob of this Applicant.  # noqa: E501

        The applicant’s date of birth  # noqa: E501

        :return: The dob of this Applicant.  # noqa: E501
        :rtype: date
        """
        return self._dob

    @dob.setter
    def dob(self, dob):
        """Sets the dob of this Applicant.

        The applicant’s date of birth  # noqa: E501

        :param dob: The dob of this Applicant.  # noqa: E501
        :type: date
        """

        self._dob = dob

    @property
    def telephone(self):
        """Gets the telephone of this Applicant.  # noqa: E501

        The applicant’s landline phone number  # noqa: E501

        :return: The telephone of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._telephone

    @telephone.setter
    def telephone(self, telephone):
        """Sets the telephone of this Applicant.

        The applicant’s landline phone number  # noqa: E501

        :param telephone: The telephone of this Applicant.  # noqa: E501
        :type: str
        """

        self._telephone = telephone

    @property
    def mobile(self):
        """Gets the mobile of this Applicant.  # noqa: E501

        The applicant’s mobile phone number  # noqa: E501

        :return: The mobile of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._mobile

    @mobile.setter
    def mobile(self, mobile):
        """Sets the mobile of this Applicant.

        The applicant’s mobile phone number  # noqa: E501

        :param mobile: The mobile of this Applicant.  # noqa: E501
        :type: str
        """

        self._mobile = mobile

    @property
    def country(self):
        """Gets the country of this Applicant.  # noqa: E501

        The country where this applicant will be checked. This must be a three-letter ISO code e.g. GBR or USA  # noqa: E501

        :return: The country of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Applicant.

        The country where this applicant will be checked. This must be a three-letter ISO code e.g. GBR or USA  # noqa: E501

        :param country: The country of this Applicant.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def nationality(self):
        """Gets the nationality of this Applicant.  # noqa: E501

        The applicant's nationality. This must be a three-letter ISO code e.g. GBR or USA  # noqa: E501

        :return: The nationality of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._nationality

    @nationality.setter
    def nationality(self, nationality):
        """Sets the nationality of this Applicant.

        The applicant's nationality. This must be a three-letter ISO code e.g. GBR or USA  # noqa: E501

        :param nationality: The nationality of this Applicant.  # noqa: E501
        :type: str
        """

        self._nationality = nationality

    @property
    def mothers_maiden_name(self):
        """Gets the mothers_maiden_name of this Applicant.  # noqa: E501

        The applicant’s mothers maiden name  # noqa: E501

        :return: The mothers_maiden_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._mothers_maiden_name

    @mothers_maiden_name.setter
    def mothers_maiden_name(self, mothers_maiden_name):
        """Sets the mothers_maiden_name of this Applicant.

        The applicant’s mothers maiden name  # noqa: E501

        :param mothers_maiden_name: The mothers_maiden_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._mothers_maiden_name = mothers_maiden_name

    @property
    def country_of_birth(self):
        """Gets the country_of_birth of this Applicant.  # noqa: E501

        The applicant’s country of birth  # noqa: E501

        :return: The country_of_birth of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._country_of_birth

    @country_of_birth.setter
    def country_of_birth(self, country_of_birth):
        """Sets the country_of_birth of this Applicant.

        The applicant’s country of birth  # noqa: E501

        :param country_of_birth: The country_of_birth of this Applicant.  # noqa: E501
        :type: str
        """

        self._country_of_birth = country_of_birth

    @property
    def town_of_birth(self):
        """Gets the town_of_birth of this Applicant.  # noqa: E501

        The applicant’s town of birth  # noqa: E501

        :return: The town_of_birth of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._town_of_birth

    @town_of_birth.setter
    def town_of_birth(self, town_of_birth):
        """Sets the town_of_birth of this Applicant.

        The applicant’s town of birth  # noqa: E501

        :param town_of_birth: The town_of_birth of this Applicant.  # noqa: E501
        :type: str
        """

        self._town_of_birth = town_of_birth

    @property
    def previous_last_name(self):
        """Gets the previous_last_name of this Applicant.  # noqa: E501

        The applicant’s previous last name  # noqa: E501

        :return: The previous_last_name of this Applicant.  # noqa: E501
        :rtype: str
        """
        return self._previous_last_name

    @previous_last_name.setter
    def previous_last_name(self, previous_last_name):
        """Sets the previous_last_name of this Applicant.

        The applicant’s previous last name  # noqa: E501

        :param previous_last_name: The previous_last_name of this Applicant.  # noqa: E501
        :type: str
        """

        self._previous_last_name = previous_last_name

    @property
    def addresses(self):
        """Gets the addresses of this Applicant.  # noqa: E501


        :return: The addresses of this Applicant.  # noqa: E501
        :rtype: list[Address]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this Applicant.


        :param addresses: The addresses of this Applicant.  # noqa: E501
        :type: list[Address]
        """

        self._addresses = addresses

    @property
    def id_numbers(self):
        """Gets the id_numbers of this Applicant.  # noqa: E501


        :return: The id_numbers of this Applicant.  # noqa: E501
        :rtype: list[IdNumber]
        """
        return self._id_numbers

    @id_numbers.setter
    def id_numbers(self, id_numbers):
        """Sets the id_numbers of this Applicant.


        :param id_numbers: The id_numbers of this Applicant.  # noqa: E501
        :type: list[IdNumber]
        """

        self._id_numbers = id_numbers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Applicant):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Address(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'flat_number': 'str',
        'building_number': 'str',
        'building_name': 'str',
        'street': 'str',
        'sub_street': 'str',
        'town': 'str',
        'postcode': 'str',
        'country': 'str',
        'start_date': 'date',
        'end_date': 'date',
        'state': 'str'
    }

    attribute_map = {
        'flat_number': 'flat_number',
        'building_number': 'building_number',
        'building_name': 'building_name',
        'street': 'street',
        'sub_street': 'sub_street',
        'town': 'town',
        'postcode': 'postcode',
        'country': 'country',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'state': 'state'
    }

    def __init__(self, flat_number=None, building_number=None, building_name=None, street=None, sub_street=None, town=None, postcode=None, country=None, start_date=None, end_date=None, state=None):  # noqa: E501
        """Address - a model defined in OpenAPI"""  # noqa: E501

        self._flat_number = None
        self._building_number = None
        self._building_name = None
        self._street = None
        self._sub_street = None
        self._town = None
        self._postcode = None
        self._country = None
        self._start_date = None
        self._end_date = None
        self._state = None
        self.discriminator = None

        if flat_number is not None:
            self.flat_number = flat_number
        if building_number is not None:
            self.building_number = building_number
        if building_name is not None:
            self.building_name = building_name
        if street is not None:
            self.street = street
        if sub_street is not None:
            self.sub_street = sub_street
        if town is not None:
            self.town = town
        if postcode is not None:
            self.postcode = postcode
        if country is not None:
            self.country = country
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if state is not None:
            self.state = state

    @property
    def flat_number(self):
        """Gets the flat_number of this Address.  # noqa: E501

        The flat number of this address  # noqa: E501

        :return: The flat_number of this Address.  # noqa: E501
        :rtype: str
        """
        return self._flat_number

    @flat_number.setter
    def flat_number(self, flat_number):
        """Sets the flat_number of this Address.

        The flat number of this address  # noqa: E501

        :param flat_number: The flat_number of this Address.  # noqa: E501
        :type: str
        """

        self._flat_number = flat_number

    @property
    def building_number(self):
        """Gets the building_number of this Address.  # noqa: E501

        The building number of this address  # noqa: E501

        :return: The building_number of this Address.  # noqa: E501
        :rtype: str
        """
        return self._building_number

    @building_number.setter
    def building_number(self, building_number):
        """Sets the building_number of this Address.

        The building number of this address  # noqa: E501

        :param building_number: The building_number of this Address.  # noqa: E501
        :type: str
        """

        self._building_number = building_number

    @property
    def building_name(self):
        """Gets the building_name of this Address.  # noqa: E501

        The building name of this address  # noqa: E501

        :return: The building_name of this Address.  # noqa: E501
        :rtype: str
        """
        return self._building_name

    @building_name.setter
    def building_name(self, building_name):
        """Sets the building_name of this Address.

        The building name of this address  # noqa: E501

        :param building_name: The building_name of this Address.  # noqa: E501
        :type: str
        """

        self._building_name = building_name

    @property
    def street(self):
        """Gets the street of this Address.  # noqa: E501

        The street of the applicant’s address  # noqa: E501

        :return: The street of this Address.  # noqa: E501
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this Address.

        The street of the applicant’s address  # noqa: E501

        :param street: The street of this Address.  # noqa: E501
        :type: str
        """

        self._street = street

    @property
    def sub_street(self):
        """Gets the sub_street of this Address.  # noqa: E501

        The sub-street of the applicant’s address  # noqa: E501

        :return: The sub_street of this Address.  # noqa: E501
        :rtype: str
        """
        return self._sub_street

    @sub_street.setter
    def sub_street(self, sub_street):
        """Sets the sub_street of this Address.

        The sub-street of the applicant’s address  # noqa: E501

        :param sub_street: The sub_street of this Address.  # noqa: E501
        :type: str
        """

        self._sub_street = sub_street

    @property
    def town(self):
        """Gets the town of this Address.  # noqa: E501

        The town of the applicant’s address  # noqa: E501

        :return: The town of this Address.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this Address.

        The town of the applicant’s address  # noqa: E501

        :param town: The town of this Address.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def postcode(self):
        """Gets the postcode of this Address.  # noqa: E501

        The postcode or ZIP of the applicant’s address  # noqa: E501

        :return: The postcode of this Address.  # noqa: E501
        :rtype: str
        """
        return self._postcode

    @postcode.setter
    def postcode(self, postcode):
        """Sets the postcode of this Address.

        The postcode or ZIP of the applicant’s address  # noqa: E501

        :param postcode: The postcode of this Address.  # noqa: E501
        :type: str
        """

        self._postcode = postcode

    @property
    def country(self):
        """Gets the country of this Address.  # noqa: E501

        The 3 character ISO country code of this address. For example, GBR is the country code for the United Kingdom  # noqa: E501

        :return: The country of this Address.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Address.

        The 3 character ISO country code of this address. For example, GBR is the country code for the United Kingdom  # noqa: E501

        :param country: The country of this Address.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def start_date(self):
        """Gets the start_date of this Address.  # noqa: E501

        The date the applicant started living at this address  # noqa: E501

        :return: The start_date of this Address.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Address.

        The date the applicant started living at this address  # noqa: E501

        :param start_date: The start_date of this Address.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Address.  # noqa: E501

        The date the applicant left this address. If current residence, leave null  # noqa: E501

        :return: The end_date of this Address.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Address.

        The date the applicant left this address. If current residence, leave null  # noqa: E501

        :param end_date: The end_date of this Address.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def state(self):
        """Gets the state of this Address.  # noqa: E501

        The address state. US states must use the USPS abbreviation (see also ISO 3166-2:US), for example AK, CA, or TX.  # noqa: E501

        :return: The state of this Address.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Address.

        The address state. US states must use the USPS abbreviation (see also ISO 3166-2:US), for example AK, CA, or TX.  # noqa: E501

        :param state: The state of this Address.  # noqa: E501
        :type: str
        """

        self._state = state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Address):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class ReportTypeGroup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'group_only': 'bool',
        'report_types': 'list[ReportType]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'group_only': 'group_only',
        'report_types': 'report_types'
    }

    def __init__(self, id=None, name=None, group_only=None, report_types=None):  # noqa: E501
        """ReportTypeGroup - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._name = None
        self._group_only = None
        self._report_types = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if group_only is not None:
            self.group_only = group_only
        if report_types is not None:
            self.report_types = report_types

    @property
    def id(self):
        """Gets the id of this ReportTypeGroup.  # noqa: E501

        The unique identifier for the group.  # noqa: E501

        :return: The id of this ReportTypeGroup.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReportTypeGroup.

        The unique identifier for the group.  # noqa: E501

        :param id: The id of this ReportTypeGroup.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ReportTypeGroup.  # noqa: E501

        The group’s name, as specified under your account.  # noqa: E501

        :return: The name of this ReportTypeGroup.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ReportTypeGroup.

        The group’s name, as specified under your account.  # noqa: E501

        :param name: The name of this ReportTypeGroup.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def group_only(self):
        """Gets the group_only of this ReportTypeGroup.  # noqa: E501

        If false, individual reports in that group can be requested; if true, all reports must be requested together.  # noqa: E501

        :return: The group_only of this ReportTypeGroup.  # noqa: E501
        :rtype: bool
        """
        return self._group_only

    @group_only.setter
    def group_only(self, group_only):
        """Sets the group_only of this ReportTypeGroup.

        If false, individual reports in that group can be requested; if true, all reports must be requested together.  # noqa: E501

        :param group_only: The group_only of this ReportTypeGroup.  # noqa: E501
        :type: bool
        """

        self._group_only = group_only

    @property
    def report_types(self):
        """Gets the report_types of this ReportTypeGroup.  # noqa: E501

        A list of report types included in this group.  # noqa: E501

        :return: The report_types of this ReportTypeGroup.  # noqa: E501
        :rtype: list[ReportType]
        """
        return self._report_types

    @report_types.setter
    def report_types(self, report_types):
        """Sets the report_types of this ReportTypeGroup.

        A list of report types included in this group.  # noqa: E501

        :param report_types: The report_types of this ReportTypeGroup.  # noqa: E501
        :type: list[ReportType]
        """

        self._report_types = report_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportTypeGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from onfido.api_client import ApiClient


class DefaultApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel_report(self, check_id, report_id, **kwargs):  # noqa: E501
        """This endpoint is for cancelling individual paused reports.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_report(check_id, report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :param str report_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.cancel_report_with_http_info(check_id, report_id, **kwargs)  # noqa: E501
        else:
            (data) = self.cancel_report_with_http_info(check_id, report_id, **kwargs)  # noqa: E501
            return data

    def cancel_report_with_http_info(self, check_id, report_id, **kwargs):  # noqa: E501
        """This endpoint is for cancelling individual paused reports.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_report_with_http_info(check_id, report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :param str report_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['check_id', 'report_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_report" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in local_var_params or
                local_var_params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `cancel_report`")  # noqa: E501
        # verify the required parameter 'report_id' is set
        if ('report_id' not in local_var_params or
                local_var_params['report_id'] is None):
            raise ValueError("Missing the required parameter `report_id` when calling `cancel_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'check_id' in local_var_params:
            path_params['check_id'] = local_var_params['check_id']  # noqa: E501
        if 'report_id' in local_var_params:
            path_params['report_id'] = local_var_params['report_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/checks/{check_id}/reports/{report_id}/cancel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_applicant(self, applicant, **kwargs):  # noqa: E501
        """Create Applicant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_applicant(applicant, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Applicant applicant: (required)
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_applicant_with_http_info(applicant, **kwargs)  # noqa: E501
        else:
            (data) = self.create_applicant_with_http_info(applicant, **kwargs)  # noqa: E501
            return data

    def create_applicant_with_http_info(self, applicant, **kwargs):  # noqa: E501
        """Create Applicant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_applicant_with_http_info(applicant, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Applicant applicant: (required)
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_applicant" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant' is set
        if ('applicant' not in local_var_params or
                local_var_params['applicant'] is None):
            raise ValueError("Missing the required parameter `applicant` when calling `create_applicant`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'applicant' in local_var_params:
            body_params = local_var_params['applicant']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Applicant',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_check(self, applicant_id, check, **kwargs):  # noqa: E501
        """Create a check  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_check(applicant_id, check, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param Check check: (required)
        :return: Check
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_check_with_http_info(applicant_id, check, **kwargs)  # noqa: E501
        else:
            (data) = self.create_check_with_http_info(applicant_id, check, **kwargs)  # noqa: E501
            return data

    def create_check_with_http_info(self, applicant_id, check, **kwargs):  # noqa: E501
        """Create a check  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_check_with_http_info(applicant_id, check, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param Check check: (required)
        :return: Check
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id', 'check']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_check" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `create_check`")  # noqa: E501
        # verify the required parameter 'check' is set
        if ('check' not in local_var_params or
                local_var_params['check'] is None):
            raise ValueError("Missing the required parameter `check` when calling `create_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'check' in local_var_params:
            body_params = local_var_params['check']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}/checks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Check',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_webhook(self, webhook, **kwargs):  # noqa: E501
        """Create a webhook  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_webhook(webhook, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Webhook webhook: (required)
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_webhook_with_http_info(webhook, **kwargs)  # noqa: E501
        else:
            (data) = self.create_webhook_with_http_info(webhook, **kwargs)  # noqa: E501
            return data

    def create_webhook_with_http_info(self, webhook, **kwargs):  # noqa: E501
        """Create a webhook  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_webhook_with_http_info(webhook, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Webhook webhook: (required)
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['webhook']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_webhook" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'webhook' is set
        if ('webhook' not in local_var_params or
                local_var_params['webhook'] is None):
            raise ValueError("Missing the required parameter `webhook` when calling `create_webhook`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'webhook' in local_var_params:
            body_params = local_var_params['webhook']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/webhooks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Webhook',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def destroy_applicant(self, applicant_id, **kwargs):  # noqa: E501
        """Delete Applicant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.destroy_applicant(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.destroy_applicant_with_http_info(applicant_id, **kwargs)  # noqa: E501
        else:
            (data) = self.destroy_applicant_with_http_info(applicant_id, **kwargs)  # noqa: E501
            return data

    def destroy_applicant_with_http_info(self, applicant_id, **kwargs):  # noqa: E501
        """Delete Applicant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.destroy_applicant_with_http_info(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method destroy_applicant" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `destroy_applicant`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_document(self, applicant_id, document_id, **kwargs):  # noqa: E501
        """Download a documents raw data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_document(applicant_id, document_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param str document_id: (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_document_with_http_info(applicant_id, document_id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_document_with_http_info(applicant_id, document_id, **kwargs)  # noqa: E501
            return data

    def download_document_with_http_info(self, applicant_id, document_id, **kwargs):  # noqa: E501
        """Download a documents raw data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_document_with_http_info(applicant_id, document_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param str document_id: (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id', 'document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_document" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `download_document`")  # noqa: E501
        # verify the required parameter 'document_id' is set
        if ('document_id' not in local_var_params or
                local_var_params['document_id'] is None):
            raise ValueError("Missing the required parameter `document_id` when calling `download_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501
        if 'document_id' in local_var_params:
            path_params['document_id'] = local_var_params['document_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}/documents/{document_id}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_live_photo(self, live_photo_id, **kwargs):  # noqa: E501
        """Download live photo  # noqa: E501

        Live photos are downloaded using this endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_live_photo(live_photo_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_photo_id: The live photo’s unique identifier. (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_live_photo_with_http_info(live_photo_id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_live_photo_with_http_info(live_photo_id, **kwargs)  # noqa: E501
            return data

    def download_live_photo_with_http_info(self, live_photo_id, **kwargs):  # noqa: E501
        """Download live photo  # noqa: E501

        Live photos are downloaded using this endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_live_photo_with_http_info(live_photo_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_photo_id: The live photo’s unique identifier. (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['live_photo_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_live_photo" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'live_photo_id' is set
        if ('live_photo_id' not in local_var_params or
                local_var_params['live_photo_id'] is None):
            raise ValueError("Missing the required parameter `live_photo_id` when calling `download_live_photo`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'live_photo_id' in local_var_params:
            path_params['live_photo_id'] = local_var_params['live_photo_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/live_photos/{live_photo_id}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_live_video(self, live_video_id, **kwargs):  # noqa: E501
        """Download live video  # noqa: E501

        Live videos are downloaded using this endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_live_video(live_video_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_video_id: The live video’s unique identifier. (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_live_video_with_http_info(live_video_id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_live_video_with_http_info(live_video_id, **kwargs)  # noqa: E501
            return data

    def download_live_video_with_http_info(self, live_video_id, **kwargs):  # noqa: E501
        """Download live video  # noqa: E501

        Live videos are downloaded using this endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_live_video_with_http_info(live_video_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_video_id: The live video’s unique identifier. (required)
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['live_video_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_live_video" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'live_video_id' is set
        if ('live_video_id' not in local_var_params or
                local_var_params['live_video_id'] is None):
            raise ValueError("Missing the required parameter `live_video_id` when calling `download_live_video`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'live_video_id' in local_var_params:
            path_params['live_video_id'] = local_var_params['live_video_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*', 'application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/live_videos/{live_video_id}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_addresses(self, postcode, **kwargs):  # noqa: E501
        """Search for addresses by postcode  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_addresses(postcode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str postcode: (required)
        :return: GenericAddressesList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_addresses_with_http_info(postcode, **kwargs)  # noqa: E501
        else:
            (data) = self.find_addresses_with_http_info(postcode, **kwargs)  # noqa: E501
            return data

    def find_addresses_with_http_info(self, postcode, **kwargs):  # noqa: E501
        """Search for addresses by postcode  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_addresses_with_http_info(postcode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str postcode: (required)
        :return: GenericAddressesList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['postcode']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_addresses" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'postcode' is set
        if ('postcode' not in local_var_params or
                local_var_params['postcode'] is None):
            raise ValueError("Missing the required parameter `postcode` when calling `find_addresses`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'postcode' in local_var_params:
            query_params.append(('postcode', local_var_params['postcode']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/addresses/pick', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GenericAddressesList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_applicant(self, applicant_id, **kwargs):  # noqa: E501
        """Retrieve Applicant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_applicant(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_applicant_with_http_info(applicant_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_applicant_with_http_info(applicant_id, **kwargs)  # noqa: E501
            return data

    def find_applicant_with_http_info(self, applicant_id, **kwargs):  # noqa: E501
        """Retrieve Applicant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_applicant_with_http_info(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_applicant" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `find_applicant`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Applicant',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_check(self, applicant_id, check_id, **kwargs):  # noqa: E501
        """Retrieve a Check  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_check(applicant_id, check_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param str check_id: (required)
        :return: CheckWithReportIds
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_check_with_http_info(applicant_id, check_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_check_with_http_info(applicant_id, check_id, **kwargs)  # noqa: E501
            return data

    def find_check_with_http_info(self, applicant_id, check_id, **kwargs):  # noqa: E501
        """Retrieve a Check  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_check_with_http_info(applicant_id, check_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param str check_id: (required)
        :return: CheckWithReportIds
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id', 'check_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_check" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `find_check`")  # noqa: E501
        # verify the required parameter 'check_id' is set
        if ('check_id' not in local_var_params or
                local_var_params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `find_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501
        if 'check_id' in local_var_params:
            path_params['check_id'] = local_var_params['check_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}/checks/{check_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CheckWithReportIds',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_document(self, applicant_id, document_id, **kwargs):  # noqa: E501
        """A single document can be retrieved by calling this endpoint with the document’s unique identifier.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_document(applicant_id, document_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param str document_id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_document_with_http_info(applicant_id, document_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_document_with_http_info(applicant_id, document_id, **kwargs)  # noqa: E501
            return data

    def find_document_with_http_info(self, applicant_id, document_id, **kwargs):  # noqa: E501
        """A single document can be retrieved by calling this endpoint with the document’s unique identifier.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_document_with_http_info(applicant_id, document_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param str document_id: (required)
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id', 'document_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_document" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `find_document`")  # noqa: E501
        # verify the required parameter 'document_id' is set
        if ('document_id' not in local_var_params or
                local_var_params['document_id'] is None):
            raise ValueError("Missing the required parameter `document_id` when calling `find_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501
        if 'document_id' in local_var_params:
            path_params['document_id'] = local_var_params['document_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}/documents/{document_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_live_photo(self, live_photo_id, **kwargs):  # noqa: E501
        """Retrieve live photo  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_live_photo(live_photo_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_photo_id: The live photo’s unique identifier. (required)
        :return: LivePhoto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_live_photo_with_http_info(live_photo_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_live_photo_with_http_info(live_photo_id, **kwargs)  # noqa: E501
            return data

    def find_live_photo_with_http_info(self, live_photo_id, **kwargs):  # noqa: E501
        """Retrieve live photo  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_live_photo_with_http_info(live_photo_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_photo_id: The live photo’s unique identifier. (required)
        :return: LivePhoto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['live_photo_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_live_photo" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'live_photo_id' is set
        if ('live_photo_id' not in local_var_params or
                local_var_params['live_photo_id'] is None):
            raise ValueError("Missing the required parameter `live_photo_id` when calling `find_live_photo`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'live_photo_id' in local_var_params:
            path_params['live_photo_id'] = local_var_params['live_photo_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/live_photos/{live_photo_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LivePhoto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_live_video(self, live_video_id, **kwargs):  # noqa: E501
        """Retrieve live video  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_live_video(live_video_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_video_id: The live video’s unique identifier. (required)
        :return: LiveVideo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_live_video_with_http_info(live_video_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_live_video_with_http_info(live_video_id, **kwargs)  # noqa: E501
            return data

    def find_live_video_with_http_info(self, live_video_id, **kwargs):  # noqa: E501
        """Retrieve live video  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_live_video_with_http_info(live_video_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_video_id: The live video’s unique identifier. (required)
        :return: LiveVideo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['live_video_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_live_video" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'live_video_id' is set
        if ('live_video_id' not in local_var_params or
                local_var_params['live_video_id'] is None):
            raise ValueError("Missing the required parameter `live_video_id` when calling `find_live_video`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'live_video_id' in local_var_params:
            path_params['live_video_id'] = local_var_params['live_video_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/live_videos/{live_video_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LiveVideo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_report(self, check_id, report_id, **kwargs):  # noqa: E501
        """A single report can be retrieved using this endpoint with the corresponding unique identifier.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_report(check_id, report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :param str report_id: (required)
        :return: Report
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_report_with_http_info(check_id, report_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_report_with_http_info(check_id, report_id, **kwargs)  # noqa: E501
            return data

    def find_report_with_http_info(self, check_id, report_id, **kwargs):  # noqa: E501
        """A single report can be retrieved using this endpoint with the corresponding unique identifier.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_report_with_http_info(check_id, report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :param str report_id: (required)
        :return: Report
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['check_id', 'report_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_report" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in local_var_params or
                local_var_params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `find_report`")  # noqa: E501
        # verify the required parameter 'report_id' is set
        if ('report_id' not in local_var_params or
                local_var_params['report_id'] is None):
            raise ValueError("Missing the required parameter `report_id` when calling `find_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'check_id' in local_var_params:
            path_params['check_id'] = local_var_params['check_id']  # noqa: E501
        if 'report_id' in local_var_params:
            path_params['report_id'] = local_var_params['report_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/checks/{check_id}/reports/{report_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Report',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_report_type_group(self, report_type_group_id, **kwargs):  # noqa: E501
        """Retrieve single report type group object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_report_type_group(report_type_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_type_group_id: (required)
        :return: ReportTypeGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_report_type_group_with_http_info(report_type_group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_report_type_group_with_http_info(report_type_group_id, **kwargs)  # noqa: E501
            return data

    def find_report_type_group_with_http_info(self, report_type_group_id, **kwargs):  # noqa: E501
        """Retrieve single report type group object  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_report_type_group_with_http_info(report_type_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str report_type_group_id: (required)
        :return: ReportTypeGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['report_type_group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_report_type_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'report_type_group_id' is set
        if ('report_type_group_id' not in local_var_params or
                local_var_params['report_type_group_id'] is None):
            raise ValueError("Missing the required parameter `report_type_group_id` when calling `find_report_type_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'report_type_group_id' in local_var_params:
            path_params['report_type_group_id'] = local_var_params['report_type_group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/report_type_groups/{report_type_group_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReportTypeGroup',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_webhook(self, webhook_id, **kwargs):  # noqa: E501
        """Retrieve a Webhook  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_webhook(webhook_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str webhook_id: (required)
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.find_webhook_with_http_info(webhook_id, **kwargs)  # noqa: E501
        else:
            (data) = self.find_webhook_with_http_info(webhook_id, **kwargs)  # noqa: E501
            return data

    def find_webhook_with_http_info(self, webhook_id, **kwargs):  # noqa: E501
        """Retrieve a Webhook  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_webhook_with_http_info(webhook_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str webhook_id: (required)
        :return: Webhook
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['webhook_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_webhook" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'webhook_id' is set
        if ('webhook_id' not in local_var_params or
                local_var_params['webhook_id'] is None):
            raise ValueError("Missing the required parameter `webhook_id` when calling `find_webhook`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'webhook_id' in local_var_params:
            path_params['webhook_id'] = local_var_params['webhook_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/webhooks/{webhook_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Webhook',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_applicants(self, **kwargs):  # noqa: E501
        """List Applicants  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_applicants(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: The page to return. The first page is `page=1`
        :param int per_page: The number of objects per page.
        :param bool include_deleted: Whether to also include applicants scheduled for deletion.
        :return: ApplicantsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_applicants_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_applicants_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_applicants_with_http_info(self, **kwargs):  # noqa: E501
        """List Applicants  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_applicants_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page: The page to return. The first page is `page=1`
        :param int per_page: The number of objects per page.
        :param bool include_deleted: Whether to also include applicants scheduled for deletion.
        :return: ApplicantsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['page', 'per_page', 'include_deleted']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_applicants" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in local_var_params:
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params:
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501
        if 'include_deleted' in local_var_params:
            query_params.append(('include_deleted', local_var_params['include_deleted']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApplicantsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_checks(self, applicant_id, **kwargs):  # noqa: E501
        """Retrieve Checks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_checks(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param int page: The page to return. The first page is `page=1`.
        :param int per_page: The number of objects per page.
        :return: ChecksList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_checks_with_http_info(applicant_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_checks_with_http_info(applicant_id, **kwargs)  # noqa: E501
            return data

    def list_checks_with_http_info(self, applicant_id, **kwargs):  # noqa: E501
        """Retrieve Checks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_checks_with_http_info(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param int page: The page to return. The first page is `page=1`.
        :param int per_page: The number of objects per page.
        :return: ChecksList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_checks" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `list_checks`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501

        query_params = []
        if 'page' in local_var_params:
            query_params.append(('page', local_var_params['page']))  # noqa: E501
        if 'per_page' in local_var_params:
            query_params.append(('per_page', local_var_params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}/checks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChecksList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_documents(self, applicant_id, **kwargs):  # noqa: E501
        """List documents  # noqa: E501

        All documents belonging to an applicant can be listed from this endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_documents(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :return: DocumentsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_documents_with_http_info(applicant_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_documents_with_http_info(applicant_id, **kwargs)  # noqa: E501
            return data

    def list_documents_with_http_info(self, applicant_id, **kwargs):  # noqa: E501
        """List documents  # noqa: E501

        All documents belonging to an applicant can be listed from this endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_documents_with_http_info(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :return: DocumentsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_documents" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `list_documents`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}/documents', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DocumentsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_live_photos(self, applicant_id, **kwargs):  # noqa: E501
        """List live photos  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_live_photos(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: The id of the applicant the live photos belong to. (required)
        :return: LivePhotosList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_live_photos_with_http_info(applicant_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_live_photos_with_http_info(applicant_id, **kwargs)  # noqa: E501
            return data

    def list_live_photos_with_http_info(self, applicant_id, **kwargs):  # noqa: E501
        """List live photos  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_live_photos_with_http_info(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: The id of the applicant the live photos belong to. (required)
        :return: LivePhotosList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_live_photos" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `list_live_photos`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'applicant_id' in local_var_params:
            query_params.append(('applicant_id', local_var_params['applicant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/live_photos', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LivePhotosList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_live_videos(self, applicant_id, **kwargs):  # noqa: E501
        """List live videos  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_live_videos(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: The id of the applicant the live videos belong to. (required)
        :return: LiveVideosList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_live_videos_with_http_info(applicant_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_live_videos_with_http_info(applicant_id, **kwargs)  # noqa: E501
            return data

    def list_live_videos_with_http_info(self, applicant_id, **kwargs):  # noqa: E501
        """List live videos  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_live_videos_with_http_info(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: The id of the applicant the live videos belong to. (required)
        :return: LiveVideosList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_live_videos" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `list_live_videos`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'applicant_id' in local_var_params:
            query_params.append(('applicant_id', local_var_params['applicant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/live_videos', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LiveVideosList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_report_type_groups(self, **kwargs):  # noqa: E501
        """Retrieve all report type groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_report_type_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ReportTypeGroupsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_report_type_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_report_type_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_report_type_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all report type groups  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_report_type_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ReportTypeGroupsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_report_type_groups" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/report_type_groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReportTypeGroupsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_reports(self, check_id, **kwargs):  # noqa: E501
        """All the reports belonging to a particular check can be listed from this endpoint.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_reports(check_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :return: ReportsList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_reports_with_http_info(check_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_reports_with_http_info(check_id, **kwargs)  # noqa: E501
            return data

    def list_reports_with_http_info(self, check_id, **kwargs):  # noqa: E501
        """All the reports belonging to a particular check can be listed from this endpoint.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_reports_with_http_info(check_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :return: ReportsList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['check_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_reports" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in local_var_params or
                local_var_params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `list_reports`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'check_id' in local_var_params:
            path_params['check_id'] = local_var_params['check_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/checks/{check_id}/reports', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReportsList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_webhooks(self, **kwargs):  # noqa: E501
        """List webhooks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_webhooks(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: WebhooksList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_webhooks_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_webhooks_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_webhooks_with_http_info(self, **kwargs):  # noqa: E501
        """List webhooks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_webhooks_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: WebhooksList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_webhooks" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/webhooks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebhooksList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def restore_applicant(self, applicant_id, **kwargs):  # noqa: E501
        """Restore Applicant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.restore_applicant(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.restore_applicant_with_http_info(applicant_id, **kwargs)  # noqa: E501
        else:
            (data) = self.restore_applicant_with_http_info(applicant_id, **kwargs)  # noqa: E501
            return data

    def restore_applicant_with_http_info(self, applicant_id, **kwargs):  # noqa: E501
        """Restore Applicant  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.restore_applicant_with_http_info(applicant_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method restore_applicant" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `restore_applicant`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}/restore', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_check(self, check_id, **kwargs):  # noqa: E501
        """Resume a Check  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_check(check_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resume_check_with_http_info(check_id, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_check_with_http_info(check_id, **kwargs)  # noqa: E501
            return data

    def resume_check_with_http_info(self, check_id, **kwargs):  # noqa: E501
        """Resume a Check  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_check_with_http_info(check_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['check_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_check" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in local_var_params or
                local_var_params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `resume_check`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'check_id' in local_var_params:
            path_params['check_id'] = local_var_params['check_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/checks/{check_id}/resume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_report(self, check_id, report_id, **kwargs):  # noqa: E501
        """This endpoint is for resuming individual paused reports.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_report(check_id, report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :param str report_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resume_report_with_http_info(check_id, report_id, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_report_with_http_info(check_id, report_id, **kwargs)  # noqa: E501
            return data

    def resume_report_with_http_info(self, check_id, report_id, **kwargs):  # noqa: E501
        """This endpoint is for resuming individual paused reports.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_report_with_http_info(check_id, report_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str check_id: (required)
        :param str report_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['check_id', 'report_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_report" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'check_id' is set
        if ('check_id' not in local_var_params or
                local_var_params['check_id'] is None):
            raise ValueError("Missing the required parameter `check_id` when calling `resume_report`")  # noqa: E501
        # verify the required parameter 'report_id' is set
        if ('report_id' not in local_var_params or
                local_var_params['report_id'] is None):
            raise ValueError("Missing the required parameter `report_id` when calling `resume_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'check_id' in local_var_params:
            path_params['check_id'] = local_var_params['check_id']  # noqa: E501
        if 'report_id' in local_var_params:
            path_params['report_id'] = local_var_params['report_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/checks/{check_id}/reports/{report_id}/resume', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_applicant(self, applicant_id, applicant, **kwargs):  # noqa: E501
        """Update Applicant  # noqa: E501

        Allows updating of an applicant’s information before any checks are created. - Partial updates - Addresses and ID numbers present will replace existing ones - Same applicant validations to create applicant   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_applicant(applicant_id, applicant, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param Applicant applicant: (required)
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_applicant_with_http_info(applicant_id, applicant, **kwargs)  # noqa: E501
        else:
            (data) = self.update_applicant_with_http_info(applicant_id, applicant, **kwargs)  # noqa: E501
            return data

    def update_applicant_with_http_info(self, applicant_id, applicant, **kwargs):  # noqa: E501
        """Update Applicant  # noqa: E501

        Allows updating of an applicant’s information before any checks are created. - Partial updates - Addresses and ID numbers present will replace existing ones - Same applicant validations to create applicant   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_applicant_with_http_info(applicant_id, applicant, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param Applicant applicant: (required)
        :return: Applicant
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id', 'applicant']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_applicant" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `update_applicant`")  # noqa: E501
        # verify the required parameter 'applicant' is set
        if ('applicant' not in local_var_params or
                local_var_params['applicant'] is None):
            raise ValueError("Missing the required parameter `applicant` when calling `update_applicant`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'applicant' in local_var_params:
            body_params = local_var_params['applicant']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Applicant',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_document(self, applicant_id, type, file, **kwargs):  # noqa: E501
        """Upload a document  # noqa: E501

        Documents are uploaded using this endpoint. Along with the file upload the relevant document type must be specified. Documents must be uploaded as a multipart form. The valid file types are: jpg, png and pdf. The file size must be between 2KB and 3MB.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_document(applicant_id, type, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param str type: The type of document. (required)
        :param file file: The file to be uploaded. (required)
        :param str side: Either the `front` or `back` of the document.
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_document_with_http_info(applicant_id, type, file, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_document_with_http_info(applicant_id, type, file, **kwargs)  # noqa: E501
            return data

    def upload_document_with_http_info(self, applicant_id, type, file, **kwargs):  # noqa: E501
        """Upload a document  # noqa: E501

        Documents are uploaded using this endpoint. Along with the file upload the relevant document type must be specified. Documents must be uploaded as a multipart form. The valid file types are: jpg, png and pdf. The file size must be between 2KB and 3MB.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_document_with_http_info(applicant_id, type, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param str type: The type of document. (required)
        :param file file: The file to be uploaded. (required)
        :param str side: Either the `front` or `back` of the document.
        :return: Document
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id', 'type', 'file', 'side']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_document" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `upload_document`")  # noqa: E501
        # verify the required parameter 'type' is set
        if ('type' not in local_var_params or
                local_var_params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `upload_document`")  # noqa: E501
        # verify the required parameter 'file' is set
        if ('file' not in local_var_params or
                local_var_params['file'] is None):
            raise ValueError("Missing the required parameter `file` when calling `upload_document`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'applicant_id' in local_var_params:
            path_params['applicant_id'] = local_var_params['applicant_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'type' in local_var_params:
            form_params.append(('type', local_var_params['type']))  # noqa: E501
        if 'side' in local_var_params:
            form_params.append(('side', local_var_params['side']))  # noqa: E501
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/applicants/{applicant_id}/documents', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Document',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_live_photo(self, applicant_id, file, **kwargs):  # noqa: E501
        """Upload live photo  # noqa: E501

        You can upload live photos to this endpoint. Like document upload, files must be uploaded as a multipart form. Valid file types are jpg, png and pdf. The file size must be between 32KB and 10MB. Live photos are validated at the point of upload to check that they contain exactly one face. This validation can be disabled by setting the advanced_validation argument to false.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_live_photo(applicant_id, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param file file: The file to be uploaded. (required)
        :param bool advanced_validation: Validates that the live photo contains exactly one face.
        :return: LivePhoto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_live_photo_with_http_info(applicant_id, file, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_live_photo_with_http_info(applicant_id, file, **kwargs)  # noqa: E501
            return data

    def upload_live_photo_with_http_info(self, applicant_id, file, **kwargs):  # noqa: E501
        """Upload live photo  # noqa: E501

        You can upload live photos to this endpoint. Like document upload, files must be uploaded as a multipart form. Valid file types are jpg, png and pdf. The file size must be between 32KB and 10MB. Live photos are validated at the point of upload to check that they contain exactly one face. This validation can be disabled by setting the advanced_validation argument to false.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_live_photo_with_http_info(applicant_id, file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str applicant_id: (required)
        :param file file: The file to be uploaded. (required)
        :param bool advanced_validation: Validates that the live photo contains exactly one face.
        :return: LivePhoto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['applicant_id', 'file', 'advanced_validation']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_live_photo" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'applicant_id' is set
        if ('applicant_id' not in local_var_params or
                local_var_params['applicant_id'] is None):
            raise ValueError("Missing the required parameter `applicant_id` when calling `upload_live_photo`")  # noqa: E501
        # verify the required parameter 'file' is set
        if ('file' not in local_var_params or
                local_var_params['file'] is None):
            raise ValueError("Missing the required parameter `file` when calling `upload_live_photo`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'applicant_id' in local_var_params:
            form_params.append(('applicant_id', local_var_params['applicant_id']))  # noqa: E501
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501
        if 'advanced_validation' in local_var_params:
            form_params.append(('advanced_validation', local_var_params['advanced_validation']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Token']  # noqa: E501

        return self.api_client.call_api(
            '/live_photos', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LivePhoto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Onfido API

    The Onfido API is used to submit check requests.  # noqa: E501

    OpenAPI spec version: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import onfido
from onfido.api.default_api import DefaultApi  # noqa: E501
from onfido.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = onfido.api.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_report(self):
        """Test case for cancel_report

        This endpoint is for cancelling individual paused reports.  # noqa: E501
        """
        pass

    def test_create_applicant(self):
        """Test case for create_applicant

        Create Applicant  # noqa: E501
        """
        pass

    def test_create_check(self):
        """Test case for create_check

        Create a check  # noqa: E501
        """
        pass

    def test_create_webhook(self):
        """Test case for create_webhook

        Create a webhook  # noqa: E501
        """
        pass

    def test_destroy_applicant(self):
        """Test case for destroy_applicant

        Delete Applicant  # noqa: E501
        """
        pass

    def test_download_document(self):
        """Test case for download_document

        Download a documents raw data  # noqa: E501
        """
        pass

    def test_download_live_photo(self):
        """Test case for download_live_photo

        Download live photo  # noqa: E501
        """
        pass

    def test_download_live_video(self):
        """Test case for download_live_video

        Download live video  # noqa: E501
        """
        pass

    def test_find_addresses(self):
        """Test case for find_addresses

        Search for addresses by postcode  # noqa: E501
        """
        pass

    def test_find_applicant(self):
        """Test case for find_applicant

        Retrieve Applicant  # noqa: E501
        """
        pass

    def test_find_check(self):
        """Test case for find_check

        Retrieve a Check  # noqa: E501
        """
        pass

    def test_find_document(self):
        """Test case for find_document

        A single document can be retrieved by calling this endpoint with the document’s unique identifier.  # noqa: E501
        """
        pass

    def test_find_live_photo(self):
        """Test case for find_live_photo

        Retrieve live photo  # noqa: E501
        """
        pass

    def test_find_live_video(self):
        """Test case for find_live_video

        Retrieve live video  # noqa: E501
        """
        pass

    def test_find_report(self):
        """Test case for find_report

        A single report can be retrieved using this endpoint with the corresponding unique identifier.  # noqa: E501
        """
        pass

    def test_find_report_type_group(self):
        """Test case for find_report_type_group

        Retrieve single report type group object  # noqa: E501
        """
        pass

    def test_find_webhook(self):
        """Test case for find_webhook

        Retrieve a Webhook  # noqa: E501
        """
        pass

    def test_list_applicants(self):
        """Test case for list_applicants

        List Applicants  # noqa: E501
        """
        pass

    def test_list_checks(self):
        """Test case for list_checks

        Retrieve Checks  # noqa: E501
        """
        pass

    def test_list_documents(self):
        """Test case for list_documents

        List documents  # noqa: E501
        """
        pass

    def test_list_live_photos(self):
        """Test case for list_live_photos

        List live photos  # noqa: E501
        """
        pass

    def test_list_live_videos(self):
        """Test case for list_live_videos

        List live videos  # noqa: E501
        """
        pass

    def test_list_report_type_groups(self):
        """Test case for list_report_type_groups

        Retrieve all report type groups  # noqa: E501
        """
        pass

    def test_list_reports(self):
        """Test case for list_reports

        All the reports belonging to a particular check can be listed from this endpoint.  # noqa: E501
        """
        pass

    def test_list_webhooks(self):
        """Test case for list_webhooks

        List webhooks  # noqa: E501
        """
        pass

    def test_restore_applicant(self):
        """Test case for restore_applicant

        Restore Applicant  # noqa: E501
        """
        pass

    def test_resume_check(self):
        """Test case for resume_check

        Resume a Check  # noqa: E501
        """
        pass

    def test_resume_report(self):
        """Test case for resume_report

        This endpoint is for resuming individual paused reports.  # noqa: E501
        """
        pass

    def test_update_applicant(self):
        """Test case for update_applicant

        Update Applicant  # noqa: E501
        """
        pass

    def test_upload_document(self):
        """Test case for upload_document

        Upload a document  # noqa: E501
        """
        pass

    def test_upload_live_photo(self):
        """Test case for upload_live_photo

        Upload live photo  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
